## Getting Started with Brython

* Brython was designed for replacing JavaScript with Python.
* This tutorial will show you how to get started quickly.

### 1. Get a web server up and running:

<i>Run from [SeleniumBase/integrations/brython](https://github.com/seleniumbase/SeleniumBase/tree/master/integrations/brython)</i>:

```bash
python -m http.server
```
You can always stop the server by using ``CTRL-C``.

### 2. Navigate to [http://localhost:8000/](http://localhost:8000/)

Now click on the examples to see Brython in action.

### 3. For more info, see the following:

* https://brython.info/
* https://pypi.org/project/brython/
* https://github.com/brython-dev/brython
